@@ -54,6 +54,7 @@ def test_get_bag_tiddler_list_404():
             method='GET')
 
     assert response['status'] == '404'
+    assert '(' not in content
 
 def test_get_bag_tiddler_list_text():
     http = httplib2.Http()
@@ -219,6 +220,7 @@ def test_put_bag():
             headers={'Accept': 'application/json'})
 
     assert response['status'] == '200'
+    assert 'etag' in response
     info = simplejson.loads(content)
     assert info['policy']['delete'] == policy_dict['delete']
 
