@@ -33,19 +33,18 @@ def string_to_tags_list(string):
 
 class Tiddler(object):
     """
-    The universal content object in the TiddlyWiki
-    universe, corresponding to a Page in other wiki
-    systems. A Tiddler has text and some associated
-    metadata. The text can be anything, but is usually
-    wikitext in some form, or Javascript code to be
-    used as a plugin.
+    The primary content object in the TiddlyWiki universe, vaguely
+    corresponding to a Page in other wiki systems. A Tiddler has
+    text and some associated metadata. The text can be anything, but
+    is usually wikitext in some form, or Javascript code to be used
+    as a plugin. It is possible for a Tiddler to container binary
+    content, such as image data.
 
-    Tiddler is intentional just a container of data.
-    That is, it has no methods which change the state
-    of attributes in the Tiddler or manipulate the tiddler.
-    Changing the attributes is done by directly changing
-    the attributes. This is done to make the Tiddler
-    easier to store and serialize in a diversity of ways.
+    A Tiddler is intentionally just a container of data. That is, it has
+    no methods which change the state of attributes in the Tiddler or
+    manipulate the tiddler. Changing the attributes is done by directly
+    changing the attributes. This is done to make the Tiddler easier to
+    store and serialize in many ways.
 
     A Tiddler has several attributes:
 
@@ -74,6 +73,7 @@ class Tiddler(object):
             'created',
             'modified',
             'modifier',
+            'creator',
             'tags',
             'fields',
             'text',
@@ -96,9 +96,10 @@ class Tiddler(object):
         self.title = title
         self.bag = bag
 
+        self._creator = ''
+        self.modifier = None
         self.created = ''
         self.modified = current_timestring()
-        self.modifier = None
         self.tags = []
         self.fields = {}
         self.text = ''
@@ -108,6 +109,27 @@ class Tiddler(object):
         # reference to the store which 'got' us
         self.store = None
 
+    def _get_creator(self):
+        """
+        Get the creator of this tiddler. If it has not been
+        set then use modifier.
+
+        Use the creator property instead.
+        """
+        if not self._creator:
+            self._creator = self.modifier
+        return self._creator
+
+    def _set_creator(self, creator):
+        """
+        Set the creator of this tiddler.
+
+        Use the creator property instead.
+        """
+        self._creator = creator
+
+    creator = property(_get_creator, _set_creator)
+
     def __repr__(self):
         """
         Make the printed tiddler include the title so we
