@@ -6,9 +6,11 @@ import simplejson
 
 from base64 import b64encode, b64decode
 
+from tiddlyweb.serializer import TiddlerFormatError
 from tiddlyweb.serializations import SerializationInterface
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.policy import Policy
+from tiddlyweb.util import binary_tiddler
 
 
 class Serialization(SerializationInterface):
@@ -34,24 +36,22 @@ class Serialization(SerializationInterface):
         """
         return simplejson.dumps([bag.name for bag in bags])
 
-    def list_tiddlers(self, bag):
+    def list_tiddlers(self, tiddlers):
         """
-        List the tiddlers in a bag as JSON.
+        List the tiddlers as JSON.
         The format is a list of dicts in
         the form described by self._tiddler_dict.
         """
         fat = self.environ.get('tiddlyweb.query', {}).get('fat', [False])[0]
         return simplejson.dumps([self._tiddler_dict(tiddler, fat) for
-            tiddler in bag.gen_tiddlers()])
+            tiddler in tiddlers])
 
     def recipe_as(self, recipe):
         """
         A recipe as a JSON dictionary.
         """
-        policy = recipe.policy
-        policy_dict = {}
-        for key in Policy.attributes:
-            policy_dict[key] = getattr(policy, key)
+        policy_dict = dict([(key, getattr(recipe.policy, key)) for
+                key in Policy.attributes])
         return simplejson.dumps(dict(desc=recipe.desc, policy=policy_dict,
             recipe=recipe.get_recipe()))
 
@@ -75,10 +75,8 @@ class Serialization(SerializationInterface):
         Create a JSON dictionary representing
         a Bag and Policy.
         """
-        policy = bag.policy
-        policy_dict = {}
-        for key in Policy.attributes:
-            policy_dict[key] = getattr(policy, key)
+        policy_dict = dict([(key, getattr(bag.policy, key)) for
+                key in Policy.attributes])
         info = dict(policy=policy_dict, desc=bag.desc)
         return simplejson.dumps(info)
 
@@ -107,14 +105,18 @@ class Serialization(SerializationInterface):
         """
         Turn a JSON dictionary into a Tiddler.
         """
-        dict_from_input = simplejson.loads(input_string)
+        try:
+            dict_from_input = simplejson.loads(input_string)
+        except simplejson.JSONDecodeError, exc:
+            raise TiddlerFormatError(
+                    'unable to make json into tiddler: %s, %s'
+                    % (tiddler.title, exc))
         accepted_keys = ['created', 'modified', 'modifier', 'tags', 'fields',
                 'text', 'type']
         for key, value in dict_from_input.iteritems():
             if value is not None and key in accepted_keys:
                 setattr(tiddler, key, value)
-        if (tiddler.type and tiddler.type != 'None' and not
-                tiddler.type.startswith('text/')):
+        if binary_tiddler(tiddler):
             tiddler.text = b64decode(tiddler.text)
 
         return tiddler
@@ -132,8 +134,7 @@ class Serialization(SerializationInterface):
             wanted_info[attribute] = getattr(tiddler, attribute, None)
         wanted_info['permissions'] = self._tiddler_permissions(tiddler)
         if fat:
-            if (tiddler.type and tiddler.type != 'None' and not
-                    tiddler.type.startswith('text/')):
+            if binary_tiddler(tiddler):
                 wanted_info['text'] = b64encode(tiddler.text)
             else:
                 wanted_info['text'] = tiddler.text
@@ -155,7 +156,6 @@ class Serialization(SerializationInterface):
                 store = tiddler.store
                 if store:
                     bag = Bag(tiddler.bag)
-                    bag.skinny = True
                     bag = store.get(bag)
                     perms = bag.policy.user_perms(
                             environ['tiddlyweb.usersign'])
