@@ -6,6 +6,7 @@ produced by a recipe.
 
 import urllib
 
+from tiddlyweb.model.collections import Tiddlers
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.recipe import Recipe
 from tiddlyweb.model.policy import create_policy_check
@@ -13,6 +14,7 @@ from tiddlyweb.store import NoRecipeError, NoBagError, \
         StoreMethodNotImplemented
 from tiddlyweb.serializer import Serializer, NoSerializationError
 from tiddlyweb.web.http import HTTP400, HTTP409, HTTP415, HTTP404
+from tiddlyweb.web.sendentity import send_entity
 from tiddlyweb.web.sendtiddlers import send_tiddlers
 from tiddlyweb.web.listentities import list_entities
 from tiddlyweb import control
@@ -47,24 +49,7 @@ def get(environ, start_response):
     """
     recipe = _determine_recipe(environ)
     recipe.policy.allows(environ['tiddlyweb.usersign'], 'read')
-
-    try:
-        serialize_type, mime_type = web.get_serialize_type(environ)
-        serializer = Serializer(serialize_type, environ)
-        serializer.object = recipe
-        content = serializer.to_string()
-    except NoSerializationError:
-        raise HTTP415('Content type %s not supported' % mime_type)
-
-    # setting the cookie for text/plain is harmless
-    start_response("200 OK",
-            [('Content-Type', mime_type),
-                ('Vary', 'Accept')])
-
-    if isinstance(content, basestring):
-        return [content]
-    else:
-        return content
+    return send_entity(environ, start_response, recipe)
 
 
 def get_tiddlers(environ, start_response):
@@ -76,37 +61,37 @@ def get_tiddlers(environ, start_response):
     store = environ['tiddlyweb.store']
     recipe = _determine_recipe(environ)
 
+    # check the recipe can be read
     recipe.policy.allows(usersign, 'read')
 
-    # get the tiddlers from the recipe and uniquify them
+    # check the bags in the recipe can be read
     try:
-        tiddlers = control.get_tiddlers_from_recipe(recipe, environ)
+        template = control.recipe_template(environ)
+        for bag_name, _ in recipe.get_recipe(template):
+            bag = Bag(bag_name)
+            bag = store.get(bag)
+            bag.policy.allows(usersign, 'read')
     except NoBagError, exc:
         raise HTTP404('recipe %s lists an unknown bag: %s' %
                 (recipe.name, exc))
 
-    tmp_bag = Bag('tmp_bag1', tmpbag=True)
+    # from this point forward we know the tiddlers are
+    # readable
 
-    # Make an optimization so we are not going
-    # to the database to load the policies of
-    # the same bag over and over.
-    policies = {}
-    for tiddler in tiddlers:
-        bag_name = tiddler.bag
-        try:
-            policies[bag_name].allows(usersign, 'read')
-        except KeyError:
-            bag = Bag(tiddler.bag)
-            bag.skinny = True
-            bag = store.get(bag)
-            policy = bag.policy
-            policies[bag_name] = policy
-            policies[bag_name].allows(usersign, 'read')
+    # get the tiddlers from the recipe and uniquify them
+    try:
+        candidate_tiddlers = control.get_tiddlers_from_recipe(recipe, environ)
+    except NoBagError, exc:
+        raise HTTP404('recipe %s lists an unknown bag: %s' %
+                (recipe.name, exc))
 
+    tiddlers = Tiddlers(store=store)
+
+    for tiddler in candidate_tiddlers:
         tiddler.recipe = recipe.name
-        tmp_bag.add_tiddler(tiddler)
+        tiddlers.add(tiddler)
 
-    return send_tiddlers(environ, start_response, tmp_bag)
+    return send_tiddlers(environ, start_response, tiddlers=tiddlers)
 
 
 def list_recipes(environ, start_response):
